Module efficient_enum::option [] [src]

Structs

EfficientOption

An option type similar to Option<(A, B)>, but where no extra data is used. Instead, some of the space in A is used to "tag the union".

EfficientOptionNoneMut

A helper type for EfficientOption, useful for adding data to is_none options.

EfficientOptionSomeMut

A helper type for EfficientOption, useful for accessing 'is_some' data and removing it.

EfficientOptionTuple

An option type similar to (A, Option<B>), but where no extra data is used. Instead, some of the space in A is used to "tag the union".

EfficientOptionTupleNoneMut

A helper type useful for accessing the lack of data or replacing it with nothing without having to use unwraps.

EfficientOptionTupleSomeMut

A helper type useful for accessing the optional data or removing it without having to use unwraps.

OptionNoneMut

A helper type for Option, useful for adding data to is_none options.

OptionSomeMut

A helper type for Option, useful for accessing 'is_some' data and removing it.

Enums

EfficientOptionMut

A helper type for EfficientOption, gives access to EfficientOptionNoneMut and EfficientOptionSomeMut variants.

EfficientOptionTupleMut

A helper type useful for accessing the lack of data or replacing it with nothing without having to use unwraps.

OptionMut

A helper type for Option, gives access to OptionNoneMut and OptionSomeMut variants.