pub struct EfficientOptionTupleInnerNone<'a, A, B: 'a, TM: 'a = TagMSB>(/* private fields */)
where
A: TaggableValue<TM, Two> + 'a;Expand description
A helper type useful for accessing the lack of data or replacing it with nothing without having to use unwraps.
Implementations
Sourceimpl<'a, TM, A, B> EfficientOptionTupleInnerNone<'a, A, B, TM>where
A: TaggableValue<TM, Two>,
impl<'a, TM, A, B> EfficientOptionTupleInnerNone<'a, A, B, TM>where
A: TaggableValue<TM, Two>,