Module efficient_enum::option
[−]
[src]
Structs
| EfficientOption |
An option type similar to |
| EfficientOptionNoneMut |
A helper type for |
| EfficientOptionSomeMut |
A helper type for |
| EfficientOptionTuple |
An option type similar to |
| EfficientOptionTupleNoneMut |
A helper type useful for accessing the lack of data or replacing it with nothing without having to use unwraps. |
| EfficientOptionTupleSomeMut |
A helper type useful for accessing the optional data or removing it without having to use unwraps. |
| OptionNoneMut |
A helper type for |
| OptionSomeMut |
A helper type for |
Enums
| EfficientOptionMut |
A helper type for |
| EfficientOptionTupleMut |
A helper type useful for accessing the lack of data or replacing it with nothing without having to use unwraps. |
| OptionMut |
A helper type for |